@@ -41,6 +41,16 @@ class GetJobInstanceListRequest(RpcRequest):
 
 	def set_GroupId(self, GroupId):  # String
 		self.add_query_param('GroupId', GroupId)
+	def get_StartTimestamp(self): # Long
+		return self.get_query_params().get('StartTimestamp')
+
+	def set_StartTimestamp(self, StartTimestamp):  # Long
+		self.add_query_param('StartTimestamp', StartTimestamp)
+	def get_EndTimestamp(self): # Long
+		return self.get_query_params().get('EndTimestamp')
+
+	def set_EndTimestamp(self, EndTimestamp):  # Long
+		self.add_query_param('EndTimestamp', EndTimestamp)
 	def get_JobId(self): # Long
 		return self.get_query_params().get('JobId')
 
@@ -51,3 +61,8 @@ class GetJobInstanceListRequest(RpcRequest):
 
 	def set_Namespace(self, Namespace):  # String
 		self.add_query_param('Namespace', Namespace)
+	def get_Status(self): # Integer
+		return self.get_query_params().get('Status')
+
+	def set_Status(self, Status):  # Integer
+		self.add_query_param('Status', Status)
