@@ -31,76 +31,26 @@ class UpdateJobRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_NamespaceSource(self): # String
-		return self.get_body_params().get('NamespaceSource')
-
-	def set_NamespaceSource(self, NamespaceSource):  # String
-		self.add_body_params('NamespaceSource', NamespaceSource)
-	def get_Description(self): # String
-		return self.get_body_params().get('Description')
-
-	def set_Description(self, Description):  # String
-		self.add_body_params('Description', Description)
 	def get_AttemptInterval(self): # Integer
 		return self.get_body_params().get('AttemptInterval')
 
 	def set_AttemptInterval(self, AttemptInterval):  # Integer
 		self.add_body_params('AttemptInterval', AttemptInterval)
-	def get_Content(self): # String
-		return self.get_body_params().get('Content')
+	def get_FailTimes(self): # Integer
+		return self.get_body_params().get('FailTimes')
 
-	def set_Content(self, Content):  # String
-		self.add_body_params('Content', Content)
-	def get_Timeout(self): # Long
-		return self.get_body_params().get('Timeout')
-
-	def set_Timeout(self, Timeout):  # Long
-		self.add_body_params('Timeout', Timeout)
-	def get_TimeoutKillEnable(self): # Boolean
-		return self.get_body_params().get('TimeoutKillEnable')
-
-	def set_TimeoutKillEnable(self, TimeoutKillEnable):  # Boolean
-		self.add_body_params('TimeoutKillEnable', TimeoutKillEnable)
+	def set_FailTimes(self, FailTimes):  # Integer
+		self.add_body_params('FailTimes', FailTimes)
 	def get_JobId(self): # Long
 		return self.get_body_params().get('JobId')
 
 	def set_JobId(self, JobId):  # Long
 		self.add_body_params('JobId', JobId)
-	def get_PageSize(self): # Integer
-		return self.get_body_params().get('PageSize')
-
-	def set_PageSize(self, PageSize):  # Integer
-		self.add_body_params('PageSize', PageSize)
 	def get_ConsumerSize(self): # Integer
 		return self.get_body_params().get('ConsumerSize')
 
 	def set_ConsumerSize(self, ConsumerSize):  # Integer
 		self.add_body_params('ConsumerSize', ConsumerSize)
-	def get_JarUrl(self): # String
-		return self.get_body_params().get('JarUrl')
-
-	def set_JarUrl(self, JarUrl):  # String
-		self.add_body_params('JarUrl', JarUrl)
-	def get_Calendar(self): # String
-		return self.get_body_params().get('Calendar')
-
-	def set_Calendar(self, Calendar):  # String
-		self.add_body_params('Calendar', Calendar)
-	def get_FailEnable(self): # Boolean
-		return self.get_body_params().get('FailEnable')
-
-	def set_FailEnable(self, FailEnable):  # Boolean
-		self.add_body_params('FailEnable', FailEnable)
-	def get_SendChannel(self): # String
-		return self.get_body_params().get('SendChannel')
-
-	def set_SendChannel(self, SendChannel):  # String
-		self.add_body_params('SendChannel', SendChannel)
-	def get_DataOffset(self): # Integer
-		return self.get_body_params().get('DataOffset')
-
-	def set_DataOffset(self, DataOffset):  # Integer
-		self.add_body_params('DataOffset', DataOffset)
 	def get_GroupId(self): # String
 		return self.get_body_params().get('GroupId')
 
@@ -111,16 +61,11 @@ class UpdateJobRequest(RpcRequest):
 
 	def set_TaskMaxAttempt(self, TaskMaxAttempt):  # Integer
 		self.add_body_params('TaskMaxAttempt', TaskMaxAttempt)
-	def get_MaxAttempt(self): # Integer
-		return self.get_body_params().get('MaxAttempt')
+	def get_DataOffset(self): # Integer
+		return self.get_body_params().get('DataOffset')
 
-	def set_MaxAttempt(self, MaxAttempt):  # Integer
-		self.add_body_params('MaxAttempt', MaxAttempt)
-	def get_MissWorkerEnable(self): # Boolean
-		return self.get_body_params().get('MissWorkerEnable')
-
-	def set_MissWorkerEnable(self, MissWorkerEnable):  # Boolean
-		self.add_body_params('MissWorkerEnable', MissWorkerEnable)
+	def set_DataOffset(self, DataOffset):  # Integer
+		self.add_body_params('DataOffset', DataOffset)
 	def get_DispatcherSize(self): # Integer
 		return self.get_body_params().get('DispatcherSize')
 
@@ -136,21 +81,11 @@ class UpdateJobRequest(RpcRequest):
 
 	def set_ExecuteMode(self, ExecuteMode):  # String
 		self.add_body_params('ExecuteMode', ExecuteMode)
-	def get_QueueSize(self): # Integer
-		return self.get_body_params().get('QueueSize')
-
-	def set_QueueSize(self, QueueSize):  # Integer
-		self.add_body_params('QueueSize', QueueSize)
 	def get_TimeExpression(self): # String
 		return self.get_body_params().get('TimeExpression')
 
 	def set_TimeExpression(self, TimeExpression):  # String
 		self.add_body_params('TimeExpression', TimeExpression)
-	def get_ClassName(self): # String
-		return self.get_body_params().get('ClassName')
-
-	def set_ClassName(self, ClassName):  # String
-		self.add_body_params('ClassName', ClassName)
 	def get_TimeoutEnable(self): # Boolean
 		return self.get_body_params().get('TimeoutEnable')
 
@@ -174,16 +109,6 @@ class UpdateJobRequest(RpcRequest):
 
 	def set_Name(self, Name):  # String
 		self.add_body_params('Name', Name)
-	def get_Namespace(self): # String
-		return self.get_body_params().get('Namespace')
-
-	def set_Namespace(self, Namespace):  # String
-		self.add_body_params('Namespace', Namespace)
-	def get_MaxConcurrency(self): # Integer
-		return self.get_body_params().get('MaxConcurrency')
-
-	def set_MaxConcurrency(self, MaxConcurrency):  # Integer
-		self.add_body_params('MaxConcurrency', MaxConcurrency)
 	def get_TimeType(self): # Integer
 		return self.get_body_params().get('TimeType')
 
@@ -194,3 +119,88 @@ class UpdateJobRequest(RpcRequest):
 
 	def set_Parameters(self, Parameters):  # String
 		self.add_body_params('Parameters', Parameters)
+	def get_NamespaceSource(self): # String
+		return self.get_body_params().get('NamespaceSource')
+
+	def set_NamespaceSource(self, NamespaceSource):  # String
+		self.add_body_params('NamespaceSource', NamespaceSource)
+	def get_Description(self): # String
+		return self.get_body_params().get('Description')
+
+	def set_Description(self, Description):  # String
+		self.add_body_params('Description', Description)
+	def get_Content(self): # String
+		return self.get_body_params().get('Content')
+
+	def set_Content(self, Content):  # String
+		self.add_body_params('Content', Content)
+	def get_Timeout(self): # Long
+		return self.get_body_params().get('Timeout')
+
+	def set_Timeout(self, Timeout):  # Long
+		self.add_body_params('Timeout', Timeout)
+	def get_TimeoutKillEnable(self): # Boolean
+		return self.get_body_params().get('TimeoutKillEnable')
+
+	def set_TimeoutKillEnable(self, TimeoutKillEnable):  # Boolean
+		self.add_body_params('TimeoutKillEnable', TimeoutKillEnable)
+	def get_PageSize(self): # Integer
+		return self.get_body_params().get('PageSize')
+
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_body_params('PageSize', PageSize)
+	def get_TaskDispatchMode(self): # String
+		return self.get_body_params().get('TaskDispatchMode')
+
+	def set_TaskDispatchMode(self, TaskDispatchMode):  # String
+		self.add_body_params('TaskDispatchMode', TaskDispatchMode)
+	def get_Calendar(self): # String
+		return self.get_body_params().get('Calendar')
+
+	def set_Calendar(self, Calendar):  # String
+		self.add_body_params('Calendar', Calendar)
+	def get_FailEnable(self): # Boolean
+		return self.get_body_params().get('FailEnable')
+
+	def set_FailEnable(self, FailEnable):  # Boolean
+		self.add_body_params('FailEnable', FailEnable)
+	def get_SendChannel(self): # String
+		return self.get_body_params().get('SendChannel')
+
+	def set_SendChannel(self, SendChannel):  # String
+		self.add_body_params('SendChannel', SendChannel)
+	def get_MaxAttempt(self): # Integer
+		return self.get_body_params().get('MaxAttempt')
+
+	def set_MaxAttempt(self, MaxAttempt):  # Integer
+		self.add_body_params('MaxAttempt', MaxAttempt)
+	def get_MissWorkerEnable(self): # Boolean
+		return self.get_body_params().get('MissWorkerEnable')
+
+	def set_MissWorkerEnable(self, MissWorkerEnable):  # Boolean
+		self.add_body_params('MissWorkerEnable', MissWorkerEnable)
+	def get_SuccessNoticeEnable(self): # Boolean
+		return self.get_body_params().get('SuccessNoticeEnable')
+
+	def set_SuccessNoticeEnable(self, SuccessNoticeEnable):  # Boolean
+		self.add_body_params('SuccessNoticeEnable', SuccessNoticeEnable)
+	def get_QueueSize(self): # Integer
+		return self.get_body_params().get('QueueSize')
+
+	def set_QueueSize(self, QueueSize):  # Integer
+		self.add_body_params('QueueSize', QueueSize)
+	def get_ClassName(self): # String
+		return self.get_body_params().get('ClassName')
+
+	def set_ClassName(self, ClassName):  # String
+		self.add_body_params('ClassName', ClassName)
+	def get_Namespace(self): # String
+		return self.get_body_params().get('Namespace')
+
+	def set_Namespace(self, Namespace):  # String
+		self.add_body_params('Namespace', Namespace)
+	def get_MaxConcurrency(self): # Integer
+		return self.get_body_params().get('MaxConcurrency')
+
+	def set_MaxConcurrency(self, MaxConcurrency):  # Integer
+		self.add_body_params('MaxConcurrency', MaxConcurrency)
